@@ -1,14 +1,13 @@
 # Tooltip : info bar at the bottom of the application ----
 tooltip <- function(id) {
-  ns <- NS(id)
-  
   tagList(
     fixedPanel(
       p(id = "tooltip", "i : "),
       left = 0,
       bottom = 0,
+      height = "50px",
       width="100%",
-      style = "background-color: #54aeff; color:#e6eaee"
+      style = "background-color: #54aeff; font-size: 16px;",
     ),
     
     # Import Javascript for tooltip, you can add/modify tooltip descriptions in www/tooltip.js
